@@ -13,17 +13,12 @@ class StreamlitWidget(StResourceList, Widget):
     Base class used for building interactive widgets using Streamlit.
     """
 
-    requirements: List[str] = ["widgets-lib"]
+    requirements: List[str] = []
     imports: List[str] = [
         "import streamlit as st",
-        "from widgets.streamlit.resource import StDataFrame",
-        "from widgets.streamlit.resource import StString",
-        "from widgets.streamlit.resource import StInteger",
-        "from widgets.streamlit.resource import StFloat",
-        "from widgets.streamlit.resource import StSelectString",
-        "from widgets.streamlit.resource import StCheckbox",
-        "from widgets.streamlit.resource_list import StResourceList",
-        "from widgets.streamlit.widget import StreamlitWidget"
+        "from widgets.streamlit.resource import *",
+        "from widgets.streamlit.resource_list import *",
+        "from widgets.streamlit.widget import *"
     ]
     extra_imports: List[str] = []
 
@@ -154,7 +149,7 @@ class StreamlitWidget(StResourceList, Widget):
             title=title,
             stlite_ver=stlite_ver,
             footer=footer,
-            requirements=self.requirements,
+            requirements=self.requirements + ["widgets-lib"],
             imports=self._imports(),
             widget_source=self._source(),
             widget_name=self._name()
